const fs = require('fs');

class ComplotDB{
    constructor(){
        this.filename = "./database/complot_db.json";
        this.actors = [];
        this.actions = [];
        this.reasons = [];
        this.readFile();
    }

    addActor(actor){
        this.actors.push(actor);
        this.saveFile();
    }

    addAction(action){
        this.actions.push(action);
        this.saveFile();
    }

    addReason(reason){
        this.reasons.push(reason);
        this.saveFile();
    }

    getAllActors(){
        return this.actors;
    }

    getAllActions(){
        return this.actions;
    }

    getAllReasons(){
        return this.reasons;
    }

    #getRandomItem(liste){
        return liste[Math.floor(Math.random()*liste.length)];
    }

    getRandomActor(){
        return this.#getRandomItem(this.actors);
    }

    getRandomAction(){
        return this.#getRandomItem(this.actions);
    }

    getRandomReason(){
        return this.#getRandomItem(this.reasons);
    }

    #enumListString(list){
        let string = '';
        for(let i = 0; i < list.length; i++){
            string += `${i} - ${list[i]}\n`;
        }
        string += "\n";
        return string;
    }

    toString(){
        let content = "```\n";
        content += "======== Actors =========\n";
        content += this.#enumListString(this.actors);
        content += "======== Actions ========\n";
        content += this.#enumListString(this.actions);
        content += "======== Reasons ========\n";
        content += this.#enumListString(this.reasons);
        content += "```";
        return content;
    }

    readFile(){
        let data = fs.readFile(this.filename, (err, data)=>{
            if (err){
                console.log("ERROR READ FILE", err);
                throw err;
            }
            const json = JSON.parse(data);
            this.actors = json.actors;
            this.reasons = json.reasons;
            this.actions = json.actions;
        });
        
    }

    saveFile(){
        let data = JSON.stringify({
            actors: this.actors, 
            actions: this.actions,
            reasons: this.reasons
        });

        fs.writeFile(this.filename, data, (err)=>{
            if(err){
                console.log("SAVE FILE ERROR", err);
            }
        });
    }


}

const instance = new ComplotDB();

module.exports = instance;